classdef SpikeSig < DataSig
% Demonstration of the definition of a sub-class of the super-class DataSig
% to work with electrophysiological signals stored in matlab files
% 
% This script is part of the Matlab course for PhD Students 2010-2011:
% http://www.sinnesphysiologie.uni-oldenburg.de/50246.html
% This program was written by Jutta Kretzberg, 02.02.2011
    
% properties inherited from super-class DataSig:
% vData        % measurement data 
% SampRate     % sampling rate
% sName        % name of the time series
% TimeUnit='s'; 	% unit used for time axis, 
                    % default value is 's' (seconds)
% vTimeAxis  (Dependent=true) % time axis in seconds, compute from sampling rate 
                     % and length of the data vector with method
                     % get.vTimeAxis(obj)
        
    properties  % special properties of this class
        Cell='Rz'      % Name of the cell recorded, 
                                % default is 'Rz'
    end
    
% methods inherited from super-class DataSig:
% set.TimeUnit
% length
% get.vTimeAxis
% plot

    methods   % special methods of this class
         % Constructor method for creating new objects of the class
        function obj = SpikeSig(sFileName, sSigName)
            load(sFileName) % load signal, sampling rate
            obj=obj@DataSig(spikedata, samprate, sSigName); % call super-class constructor
        end
        
        function m=mean(obj)  % overload function mean for this class
            m=mean(obj.vData,1)
        end
    end % methods
    
    methods (Access = protected)  
     function plotlabels(obj)
         % method to label plots of DataSig objects which do not belong
         % to SoundSig or SpikeSig subclasses.
            xlabel(['time [' obj.TimeUnit ']'])  % add x-axis label including
                                                 % TimeUnit
            ylabel('amplitude [mv]')      % add y-axis label
            title([obj.sName ' recorded from ' obj.Cell])  
            % add title including speaker name
     end
    end % protected methods
    
end

